[Secure-testing-commits] r5635 - / lib/python

Florian Weimer fw at alioth.debian.org
Sun Apr 8 21:47:10 UTC 2007


Author: fw
Date: 2007-04-08 21:47:10 +0000 (Sun, 08 Apr 2007)
New Revision: 5635

Modified:
   Makefile
   lib/python/debian_support.py
   lib/python/security_db.py
Log:
First round of adjustments for the etch release


Modified: Makefile
===================================================================
--- Makefile	2007-04-08 20:47:19 UTC (rev 5634)
+++ Makefile	2007-04-08 21:47:10 UTC (rev 5635)
@@ -7,8 +7,8 @@
 
 # MIRROR = http://merkel.debian.org/~aba/debian/
 MIRROR = http://ftp-stud.fht-esslingen.de/debian/
-SARGE_ARCHS = alpha arm hppa i386 ia64 m68k mips mipsel powerpc s390 sparc
-ETCH_ARCHS = $(SARGE_ARCHS) amd64
+SARGE_ARCHS = alpha amd64 arm hppa i386 ia64 m68k mips mipsel powerpc s390 sparc
+LENNY_ARCHS = alpha arm hppa i386 ia64 mips mipsel powerpc s390 sparc
 
 all:
 	rm -f data/security-new.db data/security-new.db.journal
@@ -39,8 +39,8 @@
 	$(PYTHON) bin/check-syntax DTSA data/DTSA/list
 	touch $@
 
-.PHONY: update-packages update-etch-security
-RELEASES = etch sid 
+.PHONY: update-packages update-testing-security
+RELEASES = lenny sid 
 update-packages:
 	set -e ; for rel in $(RELEASES) ; do \
 		for archive in main contrib non-free ; do \
@@ -48,7 +48,7 @@
 			$(MIRROR)/dists/$$rel/$$archive/source/Sources \
 			data/packages/$${rel}__$${archive}_Sources ; \
 		done ; \
-	        for arch in $(ETCH_ARCHS) ; do \
+	        for arch in $(LENNY_ARCHS) ; do \
 		  for archive in main contrib non-free ; do \
 		  $(PYTHON) bin/apt-update-file \
 		    $(MIRROR)/dists/$$rel/$$archive/binary-$$arch/Packages \
@@ -57,24 +57,24 @@
 		done ; \
 	done
 
-ST_MIRROR = http://security.debian.org/dists/etch/updates
-ST_FILE = data/packages/etch_security_
+ST_MIRROR = http://security.debian.org/dists/lenny/updates
+ST_FILE = data/packages/lenny_security_
 update-testing-security:
 	$(PYTHON) bin/apt-update-file \
 	  $(ST_MIRROR)/main/source/Sources $(ST_FILE)main_Sources
-	set -e ; for arch in $(ETCH_ARCHS) ; do \
+	set -e ; for arch in $(LENNY_ARCHS) ; do \
 	  $(PYTHON) bin/apt-update-file \
 	    $(ST_MIRROR)/main/binary-$${arch}/Packages $(ST_FILE)main_$${arch}_Packages ; \
 	  done
 
 SEC_MIRROR = http://security.debian.org/dists
 update-security:
-	for archive in woody sarge ; do \
+	for archive in sarge etch ; do \
             for section in main contrib non-free ; do \
 	    $(PYTHON) bin/apt-update-file \
 	      $(SEC_MIRROR)/$$archive/updates/$$section/source/Sources \
 	      data/packages/$${archive}_security_$${section}_Sources ; \
-	    for arch in $(ETCH_ARCHS) ; do \
+	    for arch in $(SARGE_ARCHS) ; do \
 	      $(PYTHON) bin/apt-update-file \
 	        $(SEC_MIRROR)/$$archive/updates/$$section/binary-$$arch/Packages \
 	        data/packages/$${archive}_security_$${section}_$${arch}_Packages ; \
@@ -84,7 +84,7 @@
 
 VOLATILE_MIRROR = http://volatile.debian.net/debian-volatile/dists
 update-volatile:
-	set -e && for arch in $(ETCH_ARCHS) ; do \
+	set -e && for arch in $(LENNY_ARCHS) ; do \
 	    $(PYTHON) bin/apt-update-file \
 	      $(VOLATILE_MIRROR)/sarge/volatile/main/binary-$$arch/Packages \
 	      data/packages/sarge_volatile_main_$${arch}_Packages ; \

Modified: lib/python/debian_support.py
===================================================================
--- lib/python/debian_support.py	2007-04-08 20:47:19 UTC (rev 5634)
+++ lib/python/debian_support.py	2007-04-08 21:47:10 UTC (rev 5635)
@@ -233,7 +233,7 @@
 
 def listReleases():
     releases = {}
-    rels = ("potato", "woody", "sarge", "etch", "sid")
+    rels = ("potato", "woody", "sarge", "etch", "lenny", "sid")
     for r in range(len(rels)):
         releases[rels[r]] = Release(rels[r], r)
     Release.releases = releases

Modified: lib/python/security_db.py
===================================================================
--- lib/python/security_db.py	2007-04-08 20:47:19 UTC (rev 5634)
+++ lib/python/security_db.py	2007-04-08 21:47:10 UTC (rev 5635)
@@ -368,10 +368,10 @@
             (EXISTS (SELECT * FROM package_notes_nodsa AS pnd
             WHERE pnd.bug_name = st.bug_name
             AND pnd.package = sp.name
-            AND pnd.release = 'etch')) AS no_dsa
+            AND pnd.release = 'lenny')) AS no_dsa
             FROM source_packages AS tsecp, source_package_status AS tsecst
             WHERE tsecp.name = sp.name
-            AND tsecp.release = 'etch' AND tsecp.subrelease = 'security'
+            AND tsecp.release = 'lenny' AND tsecp.subrelease = 'security'
             AND tsecp.archive = sp.archive
             AND tsecst.bug_name = st.bug_name
             AND tsecst.package = tsecp.rowid), 0) AS testing_security_fixed,
@@ -379,7 +379,7 @@
              WHERE cve_name = st.bug_name) AS remote
             FROM source_package_status AS st, source_packages AS sp
             WHERE st.vulnerable AND st.urgency <> 'unimportant'
-            AND sp.rowid = st.package AND sp.release = 'etch'
+            AND sp.rowid = st.package AND sp.release = 'lenny'
             AND sp.subrelease = ''
             ORDER BY sp.name, urgency_to_number(st.urgency), st.bug_name""")
 
@@ -442,7 +442,7 @@
                 return 999
         self.db.createscalarfunction("urgency_to_number", urgency_to_number, 1)
 
-        releases = ['potato', 'woody', 'sarge', 'etch', 'sid']
+        releases = ['potato', 'woody', 'sarge', 'etch', 'lenny', 'sid']
         def release_to_number(u):
             try:
                 return releases.index(u)
@@ -938,7 +938,7 @@
         """Calculate vulnerable packages.
 
         To each package note, a release-specific vulnerability status
         is attached.  Currently, only etch/testing is processed.
 
         Returns a list strings describing inconsistencies.
         """
@@ -954,15 +954,15 @@
         # The following does not work because stable->security ->
         # testing -> unstable propagation is no longer available.
         if False:
             # Ignore etch because sarge issues may be fast-tracked into
             # testing, bypassing unstable.
             for (bug_name, pkg_name, rel, unstable_ver, rel_ver) \
                     in list(cursor.execute(
             """SELECT a.bug_name, a.package, b.release,
             a.fixed_version, b.fixed_version
             FROM package_notes a, package_notes b
             WHERE a.bug_name = b.bug_name AND a.package = b.package
-            AND a.release = '' AND b.release NOT IN ('', 'etch')
+            AND a.release = '' AND b.release NOT IN ('', 'lenny')
             AND a.fixed_version IS NOT NULL
             AND a.fixed_version_id < b.fixed_version_id""")):
                 b = bugs.BugFromDB(cursor, bug_name)
@@ -1177,8 +1177,9 @@
             "SELECT name FROM bugs WHERE NOT not_for_us"):
 
             self._calcUnstable(c, bug_name)
-            self._calcTesting(c, bug_name, 'testing', 'etch')
-            self._calcTesting(c, bug_name, 'stable', 'sarge')
+            self._calcTesting(c, bug_name, 'testing', 'lenny')
+            self._calcTesting(c, bug_name, 'stable', 'etch')
+            self._calcTesting(c, bug_name, 'oldstable', 'sarge')
 
         return result
 
@@ -1602,7 +1603,7 @@
 
             store_value('release/1/' + release, '\n'.join(result))
 
-        for release in ('sid', 'etch', 'sarge', 'woody'):
+        for release in ('sid', 'etch', 'lenny', 'sarge'):
             gen_release(release)
 
         result = result_start
@@ -1615,7 +1616,7 @@
                 
     def calculateDebsecan(self):
         """Calculate all debsecan data."""
-        for release in ('', 'woody', 'sarge', 'etch'):
+        for release in ('', 'woody', 'sarge', 'etch', 'lenny'):
             self.calculateDebsecan0(release)
         self.calculateDebsecan1()
         
@@ -938,7 +938,7 @@
 
         To each package note, a release-specific vulnerability status
-        is attached.  Currently, only etch/testing is processed.
+        is attached.  Currently, only lenny/testing is processed.
 
         Returns a list strings describing inconsistencies.
@@ -954,15 +954,15 @@
         # testing -> unstable propagation is no longer available.
         if False:
-            # Ignore etch because sarge issues may be fast-tracked into
-            # testing, bypassing unstable.
+            # Ignore lenny/testing because stable issues may be
+            # fast-tracked into testing, bypassing unstable.
             for (bug_name, pkg_name, rel, unstable_ver, rel_ver) \
                     in list(cursor.execute(




More information about the Secure-testing-commits mailing list